@@ -9,8 +9,6 @@ from typing import Iterable, Optional, Union
 
 import gnupg  # type:ignore
 
-from aio.core import log as _log
-
 
 class GPGError(Exception):
     pass
@@ -27,7 +25,7 @@ class GPGIdentity(object):
             self,
             name: Optional[str] = None,
             email: Optional[str] = None,
-            log: Optional[Union[logging.Logger, _log.StoppableLogger]] = None,
+            log: Optional[logging.Logger] = None,
             gnupg_home: Optional[pathlib.Path] = None,
             gen_key: bool = False):
         self._provided_name = name
@@ -99,7 +97,7 @@ class GPGIdentity(object):
         return pathlib.Path(home_dir)
 
     @cached_property
-    def log(self) -> Union[logging.Logger, _log.StoppableLogger]:
+    def log(self) -> Union[logging.Logger]:
         return self._log or logging.getLogger(self.__class__.__name__)
 
     @property
